mix_annotations library

Support for doing something awesome.

Classes

GeneratedMixMethods
Flags indicating methods to generate within the Mix mixin.
GeneratedPropertyComponents
Flags specifying resolvable (DTO) generation options.
GeneratedSpecComponents
Flags to indicate external code entities (classes, extensions, etc.) to generate.
GeneratedSpecMethods
Flags indicating methods to generate within the Spec class.
GeneratedStylerMethods
Flags indicating methods to generate within the Styler mixin.
GeneratedUtilityMethods
Mixable
Annotation for configuring generated mixin for Mix classes.
MixableField
Annotation for configuring individual fields in Styler classes.
MixableSpec
Annotation for configuring generated methods and components for Spec classes.
MixableStyler
Annotation for configuring generated mixin for Styler classes.

Constants

mixable → const Mixable
mixableSpec → const MixableSpec
mixableStyler → const MixableStyler