MixableSpec class

Annotation for configuring generated methods and components for Spec classes.

methods specifies generated methods within the annotated class. components specifies external generated code like utility classes or extensions.

Constructors

MixableSpec({int methods = GeneratedSpecMethods.all, int components = GeneratedSpecComponents.all})
const

Properties

components int
final
hashCode int
The hash code for this object.
no setterinherited
methods int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited